(TeX-add-style-hook
 "library"
 (lambda ()
   (LaTeX-add-bibitems
    "gv13"
    "adh13"
    "akm18"
    "bartik91"
    "ass19"))
 :bibtex)

